@@ -29,7 +29,7 @@ def download_video(yto_params: dict, urls: list[str]) -> None:
             return ydl.download(urls)
     except Exception as e:
         error_msg = f"{type(e).__name__}: {str(e)}"
-        raise ParseError(error_msg)
+        raise RuntimeError(error_msg) from None
 
 
 class YtParser(Parser):
@@ -82,8 +82,12 @@ class YtParser(Parser):
         )
 
     def _extract_info(self, url, params=None):
-        with YoutubeDL(params or self.params) as ydl:
-            return ydl.extract_info(url, download=False)
+        try:
+            with YoutubeDL(params or self.params) as ydl:
+                return ydl.extract_info(url, download=False)
+        except Exception as e:
+            error_msg = f"{type(e).__name__}: {str(e)}"
+            raise RuntimeError(error_msg) from None
 
     # def hook(self, d):
     #     current = d.get("downloaded_bytes", 0)
@@ -153,7 +157,10 @@ class YtVideoParseResult(VideoParseResult):
         yto["outtmpl"] = f"{dir_.joinpath('ytdlp_%(id)s')}.%(ext)s"
 
         text = "下载合并中...请耐心等待..."
-        if GlobalConfig.duration_limit and self.dl.duration > GlobalConfig.duration_limit:
+        if (
+            GlobalConfig.duration_limit
+            and self.dl.duration > GlobalConfig.duration_limit
+        ):
             # 视频超过限制时长，获取最低画质
             text += f"\n视频超过{GlobalConfig.duration_limit}秒，获取最低画质"
             yto["format"] = "worstvideo* + worstaudio / worst"
@@ -169,6 +176,8 @@ class YtVideoParseResult(VideoParseResult):
             )
         except asyncio.TimeoutError:
             raise ParseError("下载超时")
+        except Exception as e:
+            raise ParseError(f"下载失败: {str(e)}")
 
         v = (
             list(dir_.glob("*.mp4"))
