@@ -95,7 +95,9 @@ class BiliParse(YtParser):
         bvid = self.get_bvid(url)
         video_info = await bili.get_video_info(bvid)
 
-        data = video_info["data"]
+        data = video_info.get("data")
+        if not data:
+            raise ParseError("获取视频信息失败")
         duration = data["View"]["duration"]
         b3, b4 = await bili.get_buvid()
         if GlobalConfig.duration_limit and duration > 5400:  # 超过90分钟直接返回封面
@@ -112,12 +114,16 @@ class BiliParse(YtParser):
             video_playurl = await bili.get_video_playurl(
                 bvid, data["View"]["cid"], b3, b4
             )
+        durl = video_playurl["data"]["durl"][0]
+        video_url = (
+            self.change_source(durl["backup_url"][0])
+            if durl.get("backup_url")
+            else durl["url"]
+        )
         return BiliVideoParseResult(
             title=data["View"]["title"],
             raw_url=url,
-            video=Video(
-                video_playurl["data"]["durl"][0]["url"], thumb_url=data["View"]["pic"]
-            ),
+            video=Video(video_url, thumb_url=data["View"]["pic"]),
         )
 
     async def ytp_parse(
@@ -158,9 +164,11 @@ class BiliParse(YtParser):
                 headers=headers,
                 params=params,
             )
-        message_formate = await formate_message(
-            "web", message_json.json()["data"]["item"]
-        )
+            message_json.raise_for_status()
+            mj = message_json.json()
+            if not (data := mj.get("data")):
+                raise ParseError(f"获取动态信息失败: {mj}")
+        message_formate = await formate_message("web", data.get("item"))
         img = await DynRender().run(message_formate)
 
         # 将渲染后的图像转换为Skia Image对象
@@ -179,6 +187,10 @@ class BiliParse(YtParser):
             except Exception:
                 raise ParseError("图片上传图床失败")
 
+    @staticmethod
+    def change_source(url: str):
+        return re.sub(r"upos-.*.bilivideo.com", "upos-sz-upcdnbda2.bilivideo.com", url)
+
 
 class BiliDownloadResult(DownloadResult):
     async def summary(self, *args, **kwargs) -> SummaryResult:
@@ -242,5 +254,14 @@ class BiliYtVideoParseResult(YtVideoParseResult):
         return BiliDownloadResult(r.pr, r.media, r.save_dir)
 
 
-class BiliYtImageParseResult(YtImageParseResult):
-    ...
+class BiliYtImageParseResult(YtImageParseResult): ...
+
+
+__all__ = [
+    "BiliParse",
+    "BiliDownloadResult",
+    "BiliYtVideoParseResult",
+    "BiliYtImageParseResult",
+    "BiliVideoParseResult",
+    "BiliImageParseResult",
+]
