@@ -1,6 +1,6 @@
 from typing import Union
 from ...deps.xhs.source import XHS
-from ..base.base import Parser
+from ..base import Parser
 from ...types import (
     VideoParseResult,
     ImageParseResult,
@@ -23,7 +23,7 @@ class XhsParser(Parser):
     __platform__ = "小红书"
     __supported_type__ = ["视频", "图文"]
     __match__ = r"^(http(s)?://)?.+(xiaohongshu|xhslink).com/.+"
-    __redirect_keywords__ = ["xhslink"]
+    __redirect_keywords__ = ["xhslink", "item"]
     __reserved_parameters__ = ["xsec_token"]
 
     async def parse(
@@ -49,3 +49,6 @@ class XhsParser(Parser):
             return ImageParseResult(
                 photo=[Image(i, ext="png") for i in result["下载地址"]], **k
             )
+
+
+__all__ = ["XhsParser"]
