@@ -7,7 +7,8 @@ class YtbParse(YtParser):
     __platform_id__ = "youtube"
     __platform__ = "Youtube"
     __supported_type__ = ["视频", "音乐"]
-    __match__ = r"^(http(s)?://).*youtu(be|.be)?(\.com)?/(?!live)(?!@).+"
+    __match__ = r"^(http(s)?://).*youtu(be|.be)?(\.com)?/(?!(live|post))(?!@).+"
+    __redirect_keywords__ = ["m.youtube.com"]
     __reserved_parameters__ = ["v", "list", "index"]
 
     async def parse(self, url: str) -> Union[YtVideoParseResult, YtImageParseResult]:
@@ -26,3 +27,6 @@ class YtbParse(YtParser):
         p = sub | super().params
         # p.pop("proxy", None)
         return p
+
+
+__all__ = ["YtbParse"]
